@@ -1,25 +1,30 @@
 from io import BytesIO
-from typing import Any, Dict, IO, Union
+from typing import Any, Dict, IO, Type, Union
 
-from omnipy.data.serializer import create_dataset_from_tarfile, create_tarfile_from_dataset
+from omnipy.data.serializer import TarFileSerializer
 
 from . import pd
+from ...data.dataset import Dataset
 from .models import PandasDataset
 
 
-class PandasDatasetToTarFileSerializer:
-    @staticmethod
-    def serialize(pandas_dataset: PandasDataset) -> Union[bytes, memoryview]:
+class PandasDatasetToTarFileSerializer(TarFileSerializer):
+    @classmethod
+    def get_supported_dataset_type(cls) -> Type[Dataset]:
+        return PandasDataset
+
+    @classmethod
+    def serialize(cls, pandas_dataset: PandasDataset) -> Union[bytes, memoryview]:
         def pandas_encode_func(pandas_data: pd.DataFrame) -> memoryview:
             csv_bytes = BytesIO()
             pandas_data.to_csv(csv_bytes, encoding='utf8', mode='b', index=False)
             return csv_bytes.getbuffer()
 
-        return create_tarfile_from_dataset(
+        return cls.create_tarfile_from_dataset(
             pandas_dataset, file_suffix='csv', data_encode_func=pandas_encode_func)
 
-    @staticmethod
-    def deserialize(tarfile_bytes: bytes) -> PandasDataset:
+    @classmethod
+    def deserialize(cls, tarfile_bytes: bytes) -> PandasDataset:
         pandas_dataset = PandasDataset()
 
         def csv_decode_func(file_stream: IO[bytes]) -> pd.DataFrame:
@@ -28,7 +33,7 @@ class PandasDatasetToTarFileSerializer:
         def python_dictify_object(obj_type: str, obj_val: Any) -> Dict:
             return {obj_type: obj_val}
 
-        create_dataset_from_tarfile(
+        cls.create_dataset_from_tarfile(
             pandas_dataset,
             tarfile_bytes,
             file_suffix='csv',
