@@ -1,21 +1,25 @@
-from typing import Any, Dict, IO
+from typing import Any, Dict, IO, Type
 
 from omnipy.data.dataset import Dataset
 from omnipy.data.model import Model
-from omnipy.data.serializer import create_dataset_from_tarfile, create_tarfile_from_dataset
+from omnipy.data.serializer import TarFileSerializer
 
 
-class RawDatasetToTarFileSerializer:
-    @staticmethod
-    def serialize(dataset: Dataset[Model[str]]) -> bytes:
+class RawDatasetToTarFileSerializer(TarFileSerializer):
+    @classmethod
+    def get_supported_dataset_type(cls) -> Type[Dataset]:
+        return Dataset[Model[str]]
+
+    @classmethod
+    def serialize(cls, dataset: Dataset[Model[str]]) -> bytes:
         def raw_encode_func(contents: str) -> bytes:
             return contents.encode('utf8')
 
-        return create_tarfile_from_dataset(
+        return cls.create_tarfile_from_dataset(
             dataset, file_suffix='raw', data_encode_func=raw_encode_func)
 
-    @staticmethod
-    def deserialize(tarfile_bytes: bytes) -> Dataset[Model[str]]:
+    @classmethod
+    def deserialize(cls, tarfile_bytes: bytes) -> Dataset[Model[str]]:
         dataset = Dataset[Model[str]]()
 
         def raw_decode_func(file_stream: IO[bytes]) -> str:
@@ -24,7 +28,7 @@ class RawDatasetToTarFileSerializer:
         def python_dictify_object(obj_type: str, obj_val: Any) -> Dict:
             return {obj_type: obj_val}
 
-        create_dataset_from_tarfile(
+        cls.create_dataset_from_tarfile(
             dataset,
             tarfile_bytes,
             file_suffix='raw',
